﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;

namespace Mirea.Api.Dto.Responses.Schedule;

/// <summary>
/// Represents information about a specific schedule entry for a lecture hall.
/// </summary>
public class LectureHallScheduleInfo
{
    /// <summary>
    /// Gets or sets the day of the week for the schedule entry.
    /// </summary>
    [Required]
    public DayOfWeek DayOfWeek { get; set; }

    /// <summary>
    /// Gets or sets the pair number for the schedule entry.
    /// </summary>
    [Required]
    public int PairNumber { get; set; }

    /// <summary>
    /// Gets or sets a value indicating whether the pair is on an even week.
    /// </summary>
    [Required]
    public bool IsEven { get; set; }

    /// <summary>
    /// Gets or sets the name of the discipline for the schedule entry.
    /// </summary>
    [Required]
    public required string Discipline { get; set; }

    /// <summary>
    /// Gets or sets the ID of the discipline for the schedule entry.
    /// </summary>
    [Required]
    public required int DisciplineId { get; set; }

    /// <summary>
    /// Gets or sets the type of occupation for the schedule entry.
    /// </summary>
    [Required]
    public required IEnumerable<string> TypeOfOccupations { get; set; }

    /// <summary>
    /// Gets or sets the names of the group for the schedule entry.
    /// </summary>
    [Required]
    public required string Group { get; set; }
    /// <summary>
    /// Gets or sets the IDs of the group for the schedule entry.
    /// </summary>
    [Required]
    public required int GroupId { get; set; }

    /// <summary>
    /// Gets or sets the names of the campuses for the schedule entry.
    /// </summary>
    public required IEnumerable<string?> Campus { get; set; }

    /// <summary>
    /// Gets or sets the IDs of the campuses for the schedule entry.
    /// </summary>
    public required IEnumerable<int?> CampusId { get; set; }

    /// <summary>
    /// Gets or sets the names of the professors for the schedule entry.
    /// </summary>
    public required IEnumerable<string?> Professors { get; set; }

    /// <summary>
    /// Gets or sets the IDs of the professors for the schedule entry.
    /// </summary>
    public required IEnumerable<int?> ProfessorsId { get; set; }

    /// <summary>
    /// Gets or sets the links to online meetings for the schedule entry.
    /// </summary>
    public required IEnumerable<string?> LinkToMeet { get; set; }
}

/// <summary>
/// Represents a response containing schedule information for a lecture hall.
/// </summary>
public class LectureHallScheduleResponse
{
    /// <summary>
    /// Gets or sets the names of the lecture halls.
    /// </summary>
    public required string LectureHalls { get; set; }

    /// <summary>
    /// Gets or sets the IDs of the lecture halls.
    /// </summary>
    public required int LectureHallsId { get; set; }

    /// <summary>
    /// Gets or sets the schedules for the lecture hall.
    /// </summary>
    [Required]
    public required IEnumerable<LectureHallScheduleInfo> Schedules { get; set; }
}
